import { b as _extends, c as _objectWithoutPropertiesLoose } from './chunk-cd704477.js';
import styled, { css } from './styled.js';
import _Avatar from 'reakit/Avatar';
import classNames from 'classnames';
import React__default, { createElement, Fragment, PureComponent, cloneElement, forwardRef, Component, createRef, Children, createContext } from 'react';
import { palette, theme } from 'styled-tools';
import { node, oneOf, string, oneOfType, bool, shape, func, number, any, element, object, arrayOf, array } from 'prop-types';
import Box from 'reakit/Box';
import 'reakit/Block';
import 'reakit/Inline';
import 'reakit/InlineBlock';
import 'reakit/Flex';
import 'reakit/InlineFlex';
import 'reakit/Grid';
import 'reakit/styled';
import 'lodash/get';

var circleProperties = css(["&{border-radius:50%;}"]);

var fitProperties = function fitProperties(props) {
  if (!props.fit) return null;

  if (props.fit === 'contain') {
    return css(["object-fit:contain;", ";", ";", ";"], function (props) {
      return props.fitPosition ? css(["object-position:", ";"], props.fitPosition) : '';
    }, theme('fannypack.Avatar.fit.base'), theme('fannypack.Avatar.fit.contain'));
  }

  if (props.fit === 'cover') {
    return css(["object-fit:cover;", ";", ";", ";"], function (props) {
      return props.fitPosition ? css(["object-position:", ";"], props.fitPosition) : '';
    }, theme('fannypack.Avatar.fit.base'), theme('fannypack.Avatar.fit.cover'));
  }

  return null;
};

var sizeProperties = {
  xsmall: css(["&{font-size:8px;width:20px;height:20px;}&{", ";}"], theme('fannypack.Avatar.sizes.xsmall')),
  small: css(["&{font-size:16px;width:40px;height:40px;}&{", ";}"], theme('fannypack.Avatar.sizes.small')),
  medium: css(["&{font-size:32px;width:80px;height:80px;}&{", ";}"], theme('fannypack.Avatar.sizes.medium')),
  large: css(["&{font-size:48px;width:100px;height:100px;}&{", ";}"], theme('fannypack.Avatar.sizes.large'))
};
var AvatarCircle = styled(Box).withConfig({
  displayName: "styled__AvatarCircle",
  componentId: "k1acy4-0"
})(["align-items:center;background-color:", ";color:", ";display:flex;justify-content:center;font-size:24px;height:", ";width:", ";", ";", ";", ";"], function (props) {
  return palette(props.palette || '')(props);
}, function (props) {
  return props.color ? props.color : palette(props.palette + "Inverted")(props);
}, function (props) {
  return typeof props.styledSize === 'number' ? props.styledSize + "px" : '60px';
}, function (props) {
  return typeof props.styledSize === 'number' ? props.styledSize + "px" : '60px';
}, function (props) {
  return props.kind === 'circle' && circleProperties;
}, function (props) {
  return typeof props.styledSize === 'string' ? sizeProperties[props.styledSize] : null;
}, theme('fannypack.Avatar.Circle.base'));
var AvatarImage = styled(_Avatar).withConfig({
  displayName: "styled__AvatarImage",
  componentId: "k1acy4-1"
})(["font-size:24px;height:", ";width:", ";", ";", ";&{", ";}", ";"], function (props) {
  return typeof props.styledSize === 'number' ? props.styledSize + "px" : '60px';
}, function (props) {
  return typeof props.styledSize === 'number' ? props.styledSize + "px" : '60px';
}, function (props) {
  return props.kind === 'circle' && circleProperties;
}, function (props) {
  return typeof props.styledSize === 'string' ? sizeProperties[props.styledSize] : null;
}, fitProperties, theme('fannypack.Avatar.Image.base'));

var defaultProps = {
  a11yLabel: undefined,
  alt: undefined,
  kind: 'square',
  className: undefined,
  color: undefined,
  fit: undefined,
  fitPosition: undefined,
  initials: undefined,
  palette: undefined,
  size: undefined,
  src: undefined
};
var Avatar = function Avatar(_ref) {
  var _classNames, _classNames2;

  var a11yLabel = _ref.a11yLabel,
      className = _ref.className,
      initials = _ref.initials,
      size = _ref.size,
      src = _ref.src,
      props = _objectWithoutPropertiesLoose(_ref, ["a11yLabel", "className", "initials", "size", "src"]);

  return createElement(Fragment, null, src && createElement(AvatarImage, _extends({
    alt: a11yLabel,
    className: classNames((_classNames = {}, _classNames[className || ''] = Boolean(className), _classNames)),
    styledSize: size,
    src: src
  }, props)), initials && createElement(AvatarCircle, _extends({
    className: classNames((_classNames2 = {}, _classNames2[className || ''] = Boolean(className), _classNames2)),
    styledSize: size
  }, props), initials.split(' ').length === 2 ? initials.match(/\b\w/g) : initials.substring(0, 2)));
};
Avatar.propTypes = {
  a11yLabel: string,
  alt: string,
  kind: oneOf(['circle', 'square']),
  color: string,
  className: string,
  fit: oneOf(['cover', 'contain']),
  fitPosition: string,
  initials: string,
  palette: string,
  size: oneOfType([number, oneOf(['default', 'xsmall', 'small', 'medium', 'large'])]),
  src: string
};
Avatar.defaultProps = defaultProps;
var C = Avatar;

export default C;
export { C as Avatar };
