import { b as _extends, c as _objectWithoutPropertiesLoose } from './chunk-cd704477.js';
import styled, { css } from './styled.js';
import { columnSpreadPropType, columnSpreadOffsetPropType } from './types.js';
import { a as ColumnsContext } from './chunk-2e24b33b.js';
import React__default, { createElement, Fragment, PureComponent, cloneElement, forwardRef, Component, createRef, Children, createContext } from 'react';
import { theme } from 'styled-tools';
import { node, oneOf, string, oneOfType, bool, shape, func, number, any, element, object, arrayOf, array } from 'prop-types';
import Box from 'reakit/Box';
import 'reakit/Block';
import 'reakit/Inline';
import 'reakit/InlineBlock';
import 'reakit/Flex';
import 'reakit/InlineFlex';
import 'reakit/Grid';
import 'reakit/styled';
import 'lodash/get';

var marginAutoOffsets = {
  left: css(["margin-left:auto;"]),
  both: css(["margin-left:auto;margin-right:auto;"]),
  right: css(["margin-right:auto;"])
};

var getWidth = function getWidth(spread) {
  return spread / 12 * 100 + "%";
};

var getSpreadProperties = function getSpreadProperties(props) {
  var minBreakpoint = props.minBreakpoint,
      spread = props.spread,
      spreadMobile = props.spreadMobile,
      spreadTablet = props.spreadTablet,
      spreadDesktop = props.spreadDesktop,
      spreadWidescreen = props.spreadWidescreen,
      spreadFullHD = props.spreadFullHD;

  if (!minBreakpoint && !spread && !spreadMobile && !spreadTablet && !spreadDesktop && !spreadWidescreen && !spreadFullHD) {
    return css(["@media (max-width:", "px){flex:none;width:100%;}"], theme('fannypack.layout.tabletBreakpoint'));
  }

  var getProperties = function getProperties(_ref) {
    var breakpoint = _ref.breakpoint,
        spread = _ref.spread;
    var properties = css(["flex:none;width:", ";"], getWidth(spread));
    if (!spread) return null;

    if (breakpoint) {
      return css(["@media (max-width:", "px){", ";}"], theme("fannypack.layout." + breakpoint), properties);
    }

    return properties;
  };

  return css(["", ";", ";", ";", ";", ";", ";", ";", ";"], getProperties({
    spread: spread
  }), getProperties({
    spread: spreadFullHD,
    breakpoint: 'fullHDBreakpoint'
  }), getProperties({
    spread: spreadWidescreen,
    breakpoint: 'widescreenBreakpoint'
  }), getProperties({
    spread: spreadDesktop,
    breakpoint: 'desktopBreakpoint'
  }), minBreakpoint !== 'tablet' && minBreakpoint !== 'mobile' && !spreadTablet && !spreadMobile && css(["@media (max-width:", "px){width:100%;}"], theme('fannypack.layout.tabletBreakpoint')), getProperties({
    spread: spreadTablet,
    breakpoint: 'tabletBreakpoint'
  }), minBreakpoint !== 'mobile' && !spreadMobile && css(["@media (max-width:", "px){width:100%;}"], theme('fannypack.layout.mobileBreakpoint')), getProperties({
    spread: spreadMobile,
    breakpoint: 'mobileBreakpoint'
  }));
};

var getSpreadOffsetProperties = function getSpreadOffsetProperties(props) {
  var spreadOffset = props.spreadOffset,
      spreadMobileOffset = props.spreadMobileOffset,
      spreadTabletOffset = props.spreadTabletOffset,
      spreadDesktopOffset = props.spreadDesktopOffset,
      spreadWidescreenOffset = props.spreadWidescreenOffset,
      spreadFullHDOffset = props.spreadFullHDOffset;

  if (!spreadOffset && !spreadMobileOffset && !spreadTabletOffset && !spreadDesktopOffset && !spreadWidescreenOffset && !spreadFullHDOffset) {
    return null;
  }

  var getProperties = function getProperties(_ref2) {
    var breakpoint = _ref2.breakpoint,
        spreadOffset = _ref2.spreadOffset;
    var properties = css(["margin-left:", ";"], getWidth(spreadOffset));
    if (!spreadOffset) return null;

    if (breakpoint) {
      return css(["@media (max-width:", "px){", ";}"], theme("fannypack.layout." + breakpoint), properties);
    }

    return properties;
  };

  if (typeof spreadOffset === 'number') {
    return css(["", ";", ";", ";", ";", ";", ";", ";", ";"], getProperties({
      spreadOffset: spreadOffset
    }), getProperties({
      spreadOffset: spreadFullHDOffset,
      breakpoint: 'fullHDBreakpoint'
    }), getProperties({
      spreadOffset: spreadWidescreenOffset,
      breakpoint: 'widescreenBreakpoint'
    }), getProperties({
      spreadOffset: spreadDesktopOffset,
      breakpoint: 'desktopBreakpoint'
    }), !spreadTabletOffset && !spreadMobileOffset && css(["@media (max-width:", "px){margin-left:0;}"], theme('fannypack.layout.tabletBreakpoint')), getProperties({
      spreadOffset: spreadTabletOffset,
      breakpoint: 'tabletBreakpoint'
    }), !spreadMobileOffset && css(["@media (max-width:", "px){margin-left:0;}"], theme('fannypack.layout.mobileBreakpoint')), getProperties({
      spreadOffset: spreadMobileOffset,
      breakpoint: 'mobileBreakpoint'
    }));
  }

  return marginAutoOffsets[spreadOffset];
};

var Column = styled(Box).withConfig({
  displayName: "styled__Column",
  componentId: "sc-1lmgd0f-0"
})(["flex:1;max-width:100%;", ";&{", ";}&{", ";}&{", ";}"], function (props) {
  return !props.isGapless ? css(["padding:", "rem;"], theme('fannypack.layout.gapFactor')) : null;
}, getSpreadProperties, getSpreadOffsetProperties, theme('fannypack.Column.base'));

var Column$1 = function Column$$1(_ref) {
  var children = _ref.children,
      className = _ref.className,
      spread = _ref.spread,
      spreadMobile = _ref.spreadMobile,
      spreadTablet = _ref.spreadTablet,
      spreadDesktop = _ref.spreadDesktop,
      spreadWidescreen = _ref.spreadWidescreen,
      spreadFullHD = _ref.spreadFullHD,
      spreadOffset = _ref.spreadOffset,
      spreadMobileOffset = _ref.spreadMobileOffset,
      spreadTabletOffset = _ref.spreadTabletOffset,
      spreadDesktopOffset = _ref.spreadDesktopOffset,
      spreadWidescreenOffset = _ref.spreadWidescreenOffset,
      spreadFullHDOffset = _ref.spreadFullHDOffset,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className", "spread", "spreadMobile", "spreadTablet", "spreadDesktop", "spreadWidescreen", "spreadFullHD", "spreadOffset", "spreadMobileOffset", "spreadTabletOffset", "spreadDesktopOffset", "spreadWidescreenOffset", "spreadFullHDOffset"]);

  return createElement(ColumnsContext.Consumer, null, function (_ref2) {
    var isGapless = _ref2.isGapless,
        minBreakpoint = _ref2.minBreakpoint;
    return createElement(Column, _extends({
      className: className,
      isGapless: isGapless,
      minBreakpoint: minBreakpoint,
      spread: spread,
      spreadMobile: spreadMobile,
      spreadTablet: spreadTablet,
      spreadDesktop: spreadDesktop,
      spreadWidescreen: spreadWidescreen,
      spreadFullHD: spreadFullHD,
      spreadOffset: spreadOffset,
      spreadMobileOffset: spreadMobileOffset,
      spreadTabletOffset: spreadTabletOffset,
      spreadDesktopOffset: spreadDesktopOffset,
      spreadWidescreenOffset: spreadWidescreenOffset,
      spreadFullHDOffset: spreadFullHDOffset
    }, props), children);
  });
};
Column$1.propTypes = {
  children: node.isRequired,
  className: string,
  spread: columnSpreadPropType,
  spreadMobile: columnSpreadPropType,
  spreadTablet: columnSpreadPropType,
  spreadDesktop: columnSpreadPropType,
  spreadWidescreen: columnSpreadPropType,
  spreadFullHD: columnSpreadPropType,
  spreadOffset: columnSpreadOffsetPropType,
  spreadMobileOffset: columnSpreadOffsetPropType,
  spreadTabletOffset: columnSpreadOffsetPropType,
  spreadDesktopOffset: columnSpreadOffsetPropType,
  spreadWidescreenOffset: columnSpreadOffsetPropType,
  spreadFullHDOffset: columnSpreadOffsetPropType
};
Column$1.defaultProps = {
  className: undefined,
  spread: undefined,
  spreadMobile: undefined,
  spreadTablet: undefined,
  spreadDesktop: undefined,
  spreadWidescreen: undefined,
  spreadFullHD: undefined,
  spreadOffset: undefined,
  spreadMobileOffset: undefined,
  spreadTabletOffset: undefined,
  spreadDesktopOffset: undefined,
  spreadWidescreenOffset: undefined,
  spreadFullHDOffset: undefined
};
var C = Column$1;

export default C;
export { C as Column };
