import { b as _extends, a as _objectSpread, c as _objectWithoutPropertiesLoose } from './chunk-cd704477.js';
import styled, { css, space } from './styled.js';
import { animateDefaultProps, animatePropTypes, placementPropType, restrictDefaultProps, restrictHidePropTypes } from './types.js';
import Overlay from 'reakit/Overlay';
import React__default, { createElement, Fragment, PureComponent, cloneElement, forwardRef, Component, createRef, Children, createContext } from 'react';
import { theme } from 'styled-tools';
import { node, oneOf, string, oneOfType, bool, shape, func, number, any, element, object, arrayOf, array } from 'prop-types';

var OverlayContainer = function OverlayContainer(_ref) {
  var children = _ref.children,
      defaultVisible = _ref.defaultVisible,
      initialState = _ref.initialState,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "defaultVisible", "initialState"]);

  return createElement(Overlay.Container, _extends({
    initialState: _objectSpread({
      visible: defaultVisible
    }, initialState)
  }, props), function (_ref2) {
    var visible = _ref2.visible,
        rest = _objectWithoutPropertiesLoose(_ref2, ["visible"]);

    return children(_objectSpread({
      isVisible: visible
    }, rest));
  });
};
var overlayContainerPropTypes = {
  children: func.isRequired,
  defaultVisible: bool,
  initialState: object
};
OverlayContainer.propTypes = overlayContainerPropTypes;
var overlayContainerDefaultProps = {
  defaultVisible: false,
  initialState: {}
};
OverlayContainer.defaultProps = overlayContainerDefaultProps;

var getPlacementAttributes = function getPlacementAttributes(props) {
  if (!props.placement) return null;

  var getHiddenAttributes = function getHiddenAttributes(_ref) {
    var transformX = _ref.transformX,
        transformY = _ref.transformY;
    return function (props) {
      return css(["&[aria-hidden='true']{transform:", ";}"], "translate3d(" + (props.slide ? transformX : '0') + ", " + (props.slide ? transformY : '0') + ", 0px) " + (props.expand ? 'scale(0.01)' : ''));
    };
  };

  var placementAttributes = {
    // @ts-ignore
    top: css(["top:", "em;left:50%;transform:translate3d(-50%,0,0px);", ";"], space(5), getHiddenAttributes({
      transformX: '-50%',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    bottom: css(["bottom:", "em;left:50%;transform:translate3d(-50%,0,0px);", ";"], space(5), getHiddenAttributes({
      transformX: '-50%',
      transformY: 'calc(50% + 100%)'
    })),
    // @ts-ignore
    left: css(["top:50%;left:", "em;transform:translate3d(0px,-50%,0px);", ";"], space(5), getHiddenAttributes({
      transformX: 'calc(50% - 100%)',
      transformY: '-50%'
    })),
    // @ts-ignore
    right: css(["top:50%;right:", "em;transform:translate3d(0px,-50%,0px);", ";"], space(5), getHiddenAttributes({
      transformX: 'calc(50% + 100%)',
      transformY: '-50%'
    })),
    // @ts-ignore
    'top-start': css(["top:", "em;left:", "em;transform:translate3d(0,0,0px);", ";"], space(5), space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    'top-end': css(["top:", "em;right:", "em;transform:translate3d(0,0,0px);", ";"], space(5), space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    'bottom-end': css(["bottom:", "em;right:", "em;transform:translate3d(0,0,0px);", ";"], space(5), space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% + 100%)'
    })),
    // @ts-ignore
    'bottom-start': css(["bottom:", "em;left:", "em;transform:translate3d(0,0,0px);", ";"], space(5), space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% + 100%)'
    }))
  };
  return css(["top:unset;left:unset;", ";"], placementAttributes[props.placement]);
};

var OverlayHide = styled(Overlay.Hide).withConfig({
  displayName: "styled__OverlayHide",
  componentId: "sc-1t69wy-0"
})(["", ";"], theme('fannypack.Overlay.Hide.base'));
var OverlayShow = styled(Overlay.Show).withConfig({
  displayName: "styled__OverlayShow",
  componentId: "sc-1t69wy-1"
})(["", ";"], theme('fannypack.Overlay.Show.base'));
var OverlayToggle = styled(Overlay.Toggle).withConfig({
  displayName: "styled__OverlayToggle",
  componentId: "sc-1t69wy-2"
})(["", ";"], theme('fannypack.Overlay.Toggle.base'));
var _Overlay = styled(Overlay).withConfig({
  displayName: "styled",
  componentId: "sc-1t69wy-3"
})(["&{", ";}", ";"], getPlacementAttributes, theme('fannypack.Overlay.base'));

var OverlayHide$1 = forwardRef(function (_ref, ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  return (// @ts-ignore
    createElement(OverlayHide, _extends({}, props, {
      ref: ref
    }), children)
  );
});
var overlayHidePropTypes = {
  children: node,
  hide: func.isRequired,
  onClick: func
};
OverlayHide$1.propTypes = overlayHidePropTypes;
var overlayHideDefaultProps = {
  children: null,
  onClick: undefined
};
OverlayHide$1.defaultProps = overlayHideDefaultProps; // @ts-ignore

var C = OverlayHide$1;

var OverlayShow$1 = function OverlayShow$$1(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  return createElement(OverlayShow, props, children);
};
var overlayShowPropTypes = {
  children: node,
  onClick: func,
  show: func.isRequired
};
OverlayShow$1.propTypes = overlayShowPropTypes;
var overlayShowDefaultProps = {
  children: null,
  onClick: undefined
};
OverlayShow$1.defaultProps = overlayShowDefaultProps; // @ts-ignore

var C$1 = OverlayShow$1;

var OverlayToggle$1 = function OverlayToggle$$1(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  return createElement(OverlayToggle, props, children);
};
OverlayToggle$1.propTypes = {
  children: node,
  onClick: func,
  toggle: func.isRequired
};
OverlayToggle$1.defaultProps = {
  children: null,
  onClick: undefined
};
var C$2 = OverlayToggle$1;

var Overlay$1 = function Overlay$$1(_ref) {
  var children = _ref.children,
      isVisible = _ref.isVisible,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "isVisible"]);

  return createElement(_Overlay, _extends({
    visible: isVisible
  }, props), children);
};
Overlay$1.Container = OverlayContainer;
Overlay$1.Hide = C;
Overlay$1.Show = C$1;
Overlay$1.Toggle = C$2;
var overlayPropTypes = _objectSpread({
  children: node.isRequired,
  className: string,
  isVisible: bool,
  placement: placementPropType
}, animatePropTypes, restrictHidePropTypes);
Overlay$1.propTypes = overlayPropTypes;
var overlayDefaultProps = _objectSpread({
  className: undefined,
  isVisible: false,
  placement: undefined
}, animateDefaultProps, restrictDefaultProps, {
  hideOnEsc: true
});
Overlay$1.defaultProps = overlayDefaultProps;
var C$3 = Overlay$1;

export { C$3 as a, overlayPropTypes as b, overlayDefaultProps as c, OverlayContainer as d, overlayContainerDefaultProps as e, overlayContainerPropTypes as f, overlayHideDefaultProps as g, overlayHidePropTypes as h, overlayShowDefaultProps as i, overlayShowPropTypes as j, C as k, C$1 as l, C$2 as m };
