import { b as _extends, c as _objectWithoutPropertiesLoose, a as _objectSpread } from './chunk-cd704477.js';
import styled, { css } from './styled.js';
import { Spinner } from './Spinner.js';
import { a as FieldWrapper, b as fieldWrapperDefaultProps, c as fieldWrapperPropTypes } from './chunk-b8380805.js';
import use from 'reakit/use';
import Input from 'reakit/Input';
import React__default, { createElement, Fragment, PureComponent, cloneElement, forwardRef, Component, createRef, Children, createContext } from 'react';
import { palette, theme } from 'styled-tools';
import { node, oneOf, string, oneOfType, bool, shape, func, number, any, element, object, arrayOf, array } from 'prop-types';
import Box from 'reakit/Box';
import 'reakit/Block';
import 'reakit/Inline';
import 'reakit/InlineBlock';
import 'reakit/Flex';
import 'reakit/InlineFlex';
import 'reakit/Grid';
import 'reakit/styled';
import 'lodash/get';
import './Text.js';
import './chunk-d1ea7076.js';
import './Label.js';
import 'reakit/Label';
import 'reakit/Field';

var LoadingSpinner = styled(Spinner).withConfig({
  displayName: "styled__LoadingSpinner",
  componentId: "sc-1okmeud-0"
})(["position:absolute;width:15px;height:15px;top:12px;right:10px;z-index:1;"]);
var sizeProperties = {
  small: css(["font-size:0.8rem;& + ", "{width:10px;height:10px;top:10px;}&{", ";}"], LoadingSpinner, theme('fannypack.Textarea.sizes.small')),
  medium: css(["font-size:1.25rem;& + ", "{width:20px;height:20px;top:15px;right:10px;}&{", ";}"], LoadingSpinner, theme('fannypack.Textarea.sizes.medium')),
  large: css(["font-size:1.5rem;& + ", "{width:25px;height:25px;top:16px;right:12px;}&{", ";}"], LoadingSpinner, theme('fannypack.Textarea.sizes.large'))
};
var stateProperties = css(["border-color:", ";box-shadow:", " 0px 0px 0px 1px !important;"], function (props) {
  return palette(props.state + "300")(props);
}, function (props) {
  return palette(props.state + "300")(props);
});
var _Textarea = styled(use(Input, 'textarea')).withConfig({
  displayName: "styled",
  componentId: "sc-1okmeud-1"
})(["border:1px solid #bdbdbd;box-shadow:inset 0px 1px 2px #e5e5e5;border-radius:0.2em;width:100%;padding:0.4em 0.6em;&[disabled]{background-color:", ";box-shadow:unset;color:", ";&{", ";}}&:focus{outline:unset;z-index:2;border-color:", ";box-shadow:", " 0px 0px 0px 1px !important;&{", ";}}&::placeholder{opacity:0.6;&{", ";}}&{", ";}&{", ";}", ";"], palette('white700'), palette('gray400'), theme('fannypack.Textarea.disabled'), palette('primary'), palette('primary'), theme('fannypack.Textarea.focus'), theme('fannypack.Textarea.placeholder'), function (props) {
  return props.styledSize && sizeProperties[props.styledSize];
}, function (props) {
  return props.state && stateProperties;
}, theme('fannypack.Textarea.base'));

var Textarea = function Textarea(_ref) {
  var a11yId = _ref.a11yId,
      a11yLabel = _ref.a11yLabel,
      isLoading = _ref.isLoading,
      isRequired = _ref.isRequired,
      size = _ref.size,
      state = _ref.state,
      props = _objectWithoutPropertiesLoose(_ref, ["a11yId", "a11yLabel", "isLoading", "isRequired", "size", "state"]);

  return createElement(Box, {
    relative: true
  }, createElement(_Textarea, _extends({
    "aria-invalid": state === 'danger',
    "aria-label": a11yLabel,
    "aria-required": isRequired,
    id: a11yId,
    styledSize: size,
    state: state
  }, props)), isLoading && createElement(LoadingSpinner, {
    color: "text"
  }));
};
var textareaPropTypes = {
  a11yId: string,
  a11yLabel: string,
  autoComplete: string,
  autoFocus: bool,
  children: node,
  className: string,
  defaultValue: string,
  disabled: bool,
  isFullWidth: bool,
  isLoading: bool,
  isRequired: bool,
  name: string,
  size: string,
  maxLength: number,
  minLength: number,
  pattern: string,
  placeholder: string,
  readOnly: bool,
  rows: number,
  spellCheck: bool,
  state: string,
  value: string,
  onBlur: func,
  onChange: func,
  onFocus: func
};
Textarea.propTypes = textareaPropTypes;
var textareaDefaultProps = {
  a11yId: undefined,
  a11yLabel: undefined,
  autoComplete: undefined,
  autoFocus: false,
  className: undefined,
  defaultValue: undefined,
  disabled: false,
  isFullWidth: false,
  isLoading: false,
  isRequired: false,
  maxLength: undefined,
  minLength: undefined,
  name: undefined,
  onBlur: undefined,
  onChange: undefined,
  onFocus: undefined,
  pattern: undefined,
  placeholder: undefined,
  readOnly: undefined,
  rows: 3,
  spellCheck: undefined,
  size: 'default',
  state: undefined,
  value: undefined
};
Textarea.defaultProps = textareaDefaultProps; // @ts-ignore

var TextareaField = function TextareaField(_ref) {
  var a11yId = _ref.a11yId,
      a11yLabel = _ref.a11yLabel,
      description = _ref.description,
      hint = _ref.hint,
      isLoading = _ref.isLoading,
      isOptional = _ref.isOptional,
      isRequired = _ref.isRequired,
      label = _ref.label,
      size = _ref.size,
      state = _ref.state,
      validationText = _ref.validationText,
      props = _objectWithoutPropertiesLoose(_ref, ["a11yId", "a11yLabel", "description", "hint", "isLoading", "isOptional", "isRequired", "label", "size", "state", "validationText"]);

  return createElement(FieldWrapper, {
    a11yId: a11yId,
    description: description,
    hint: hint,
    isOptional: isOptional,
    isRequired: isRequired,
    label: label,
    state: state,
    validationText: validationText
  }, function (_ref2) {
    var elementProps = _ref2.elementProps;
    return createElement(Textarea, _extends({}, props, elementProps));
  });
};
TextareaField.propTypes = _objectSpread({}, fieldWrapperPropTypes, textareaPropTypes);
TextareaField.defaultProps = _objectSpread({}, fieldWrapperDefaultProps, textareaDefaultProps); // @ts-ignore

var C$1 = TextareaField;

export default Textarea;
export { Textarea, C$1 as TextareaField };
