import { b as _extends, a as _objectSpread, c as _objectWithoutPropertiesLoose } from './chunk-cd704477.js';
import React__default, { createElement, Fragment, PureComponent, cloneElement, forwardRef, Component, createRef, Children, createContext } from 'react';

var FIELDS_WITH_FIELD_WRAPPERS = ['CheckboxField', 'InputField', 'RadioField', 'RadioGroupField', 'SelectField', 'SelectMenuField', 'SwitchField', 'TextareaField'];
var SELECT_MENUS = ['SelectMenu', 'SelectMenuField'];

var bindFns = function bindFns() {
  for (var _len = arguments.length, fns = new Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }

  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    fns.forEach(function (fn) {
      return fn && fn.apply(void 0, args);
    });
  };
};

function formikField(Component$$1) {
  return function (_ref) {
    var field = _ref.field,
        form = _ref.form,
        props = _objectWithoutPropertiesLoose(_ref, ["field", "form"]);

    var overrideProps = {};

    if (FIELDS_WITH_FIELD_WRAPPERS.includes(Component$$1.name)) {
      var state = form.touched[field.name] && form.errors[field.name] ? 'danger' : undefined;

      if (props.state) {
        state = props.state;
      }

      var validationText = form.touched[field.name] && form.errors[field.name] ? form.errors[field.name] : undefined;

      if (props.validationText) {
        validationText = props.validationText;
      }

      overrideProps = _objectSpread({}, overrideProps, {
        state: state,
        validationText: validationText
      });
    }

    var onBlur = field.onBlur;
    var onChange = field.onChange;

    if (SELECT_MENUS.includes(Component$$1.name)) {
      onBlur = function onBlur() {
        return form.setFieldTouched(field.name);
      }; // @ts-ignore


      onChange = function onChange(value, option, newValues) {
        return form.setFieldValue(field.name, newValues);
      };
    }

    overrideProps = _objectSpread({}, overrideProps, {
      onBlur: bindFns(onBlur, props.onBlur),
      onChange: bindFns(onChange, props.onChange)
    });
    return createElement(Component$$1, _extends({}, props, field, overrideProps));
  };
}
function reduxFormField(Component$$1) {
  return function (_ref2) {
    var input = _ref2.input,
        meta = _ref2.meta,
        props = _objectWithoutPropertiesLoose(_ref2, ["input", "meta"]);

    var overrideProps = {};

    if (FIELDS_WITH_FIELD_WRAPPERS.includes(Component$$1.name)) {
      var state = meta.touched && meta.error ? 'danger' : undefined;

      if (props.state) {
        state = props.state;
      }

      var validationText = meta.touched && meta.error ? meta.error : undefined;

      if (props.validationText) {
        validationText = props.validationText;
      }

      overrideProps = _objectSpread({}, overrideProps, {
        state: state,
        validationText: validationText
      });
    }

    var onBlur = input.onBlur;
    var onChange = input.onChange;

    if (SELECT_MENUS.includes(Component$$1.name)) {
      // @ts-ignore
      onChange = function onChange(value, option, newValues) {
        return input.onChange(newValues);
      };

      onBlur = function onBlur() {
        return input.onBlur(input.value);
      };
    }

    overrideProps = _objectSpread({}, overrideProps, {
      onBlur: bindFns(onBlur, props.onBlur),
      onChange: bindFns(onChange, props.onChange)
    });
    return createElement(Component$$1, _extends({}, props, input, overrideProps));
  };
}

export { formikField, reduxFormField };
