import { a as _objectSpread } from './chunk-cd704477.js';
import { space, palette } from './styled.js';
import parseIcons from './parseIcons.js';
import { a as _defaultPalette } from './chunk-b58fa33f.js';
import * as faInfoCircle from '@fortawesome/free-solid-svg-icons/faInfoCircle';
import * as faExclamationTriangle from '@fortawesome/free-solid-svg-icons/faExclamationTriangle';
import * as faCheckCircle from '@fortawesome/free-solid-svg-icons/faCheckCircle';
import * as faExclamationCircle from '@fortawesome/free-solid-svg-icons/faExclamationCircle';
import * as faTimes from '@fortawesome/free-solid-svg-icons/faTimes';
import _get from 'lodash/get';

var global = (function (overrides) {
  return _objectSpread({
    fontFamily: "system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif",
    fontSize: 16
  }, _get(overrides, 'global', {}));
});

var layout = (function (overrides) {
  return _objectSpread({
    gapFactor: space(2),
    mobileBreakpoint: 480,
    tabletBreakpoint: 768,
    desktopBreakpoint: 1024,
    widescreenBreakpoint: 1200,
    fullHDBreakpoint: 1440,
    minorUnit: 4,
    majorUnit: 8
  }, _get(overrides, 'layout', {}));
});

var fontSizes = (function (overrides) {
  return _objectSpread({
    100: 0.75,
    150: 0.875,
    200: 1,
    300: 1.25,
    400: 1.5,
    500: 2,
    600: 2.5,
    700: 3,
    800: 3.75,
    900: 4.5
  }, _get(overrides, 'fontSizes', {}));
});

var fontWeights = (function (overrides) {
  return _objectSpread({
    normal: 400,
    semibold: 600,
    bold: 700
  }, _get(overrides, 'fontWeights', {}));
});

var Container = (function (overrides) {
  return _objectSpread({
    fluidMargin: '0 2rem',
    tabletMargin: '0 1rem'
  }, _get(overrides, 'Container', {}));
});

var FieldSet = (function (overrides) {
  return _objectSpread({
    spacing: 'major-3'
  }, _get(overrides, 'FieldSet', {}));
});

var parseOverrideIcons = function parseOverrideIcons(icons) {
  return icons.reduce(function (currentIcons, iconSet) {
    return _objectSpread({}, currentIcons, parseIcons(iconSet.icons, {
      type: iconSet.type,
      prefix: iconSet.prefix
    }));
  }, {});
};

var Icon = (function (overrides) {
  return _objectSpread({}, _get(overrides, 'Icon', {}), {
    icons: _objectSpread({}, parseIcons([faInfoCircle, faExclamationTriangle, faCheckCircle, faExclamationCircle, faTimes], {
      type: 'font-awesome-standalone'
    }), parseOverrideIcons(_get(overrides, 'Icon.iconSets', [])), _get(overrides, 'Icon.icons', {})),
    iconNames: _objectSpread({
      info: 'info-circle',
      warning: 'exclamation-triangle',
      success: 'check-circle',
      danger: 'exclamation-circle'
    }, _get(overrides, 'Icon.iconNames', {}))
  });
});

var LayoutSet = (function (overrides) {
  return _objectSpread({
    spacing: 'major-4'
  }, _get(overrides, 'LayoutSet', {}));
});

var Pane = (function (overrides) {
  return _objectSpread({}, _get(overrides, 'Pane', {}), {
    elevations: _objectSpread({
      100: 4,
      200: 8,
      300: 12,
      400: 24
    }, _get(overrides, 'Pane.elevations', {}))
  });
});

var Table = (function (overrides) {
  return _objectSpread({
    borderColor: palette('gray100'),
    spacing: space(2)
  }, _get(overrides, 'Table', {}), {
    hover: _objectSpread({
      backgroundColor: palette('white700')
    }, _get(overrides, 'Table.hover', {})),
    striped: _objectSpread({
      backgroundColor: palette('white600')
    }, _get(overrides, 'Table.striped', {}))
  });
});

function theme(overrides) {
  if (overrides === void 0) {
    overrides = {};
  }

  return _objectSpread({}, overrides, {
    global: global(overrides),
    palette: _defaultPalette(overrides),
    layout: layout(overrides),
    fontSizes: fontSizes(overrides),
    fontWeights: fontWeights(overrides),
    Container: Container(overrides),
    FieldSet: FieldSet(overrides),
    Icon: Icon(overrides),
    LayoutSet: LayoutSet(overrides),
    Pane: Pane(overrides),
    Table: Table(overrides)
  });
}

export { theme as a };
