import { palette, css, space, theme } from './styled.js';
import { a as _defaultPalette } from './chunk-b58fa33f.js';
import { c as isInteractive } from './chunk-b1ec3790.js';
import { a as defaultTheme } from './chunk-e370c1b3.js';
import { darken } from 'polished';
import 'reakit/styled';
import 'lodash/get';
import 'styled-tools';
import './chunk-cd704477.js';
import './chunk-51b7d577.js';
import './parseIcons.js';
import './chunk-d1ea7076.js';
import 'reakit/Box';
import 'reakit/Block';
import 'reakit/Inline';
import 'reakit/InlineBlock';
import 'reakit/Flex';
import 'reakit/InlineFlex';
import 'reakit/Grid';
import 'react';
import 'airbnb-prop-types';
import 'prop-types';
import 'reakit/Button';
import '@fortawesome/free-solid-svg-icons/faInfoCircle';
import '@fortawesome/free-solid-svg-icons/faExclamationTriangle';
import '@fortawesome/free-solid-svg-icons/faCheckCircle';
import '@fortawesome/free-solid-svg-icons/faExclamationCircle';
import '@fortawesome/free-solid-svg-icons/faTimes';

var global = {
  fontFamily: "'Lato', system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif",
  fallbackFontFamily: "system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif"
};

var webFontLoader = {
  google: {
    families: ['Lato:400,700,900']
  }
};

var layout = {
  mobileBreakpoint: 600
};

var fontWeights = {
  normal: 400,
  semibold: 700,
  bold: 900
};

var _palette = {
  default: 'white',
  text: '#333231',
  primary200: '#d2f1fa',
  primary300: '#a4dbeb',
  primary400: '#51afc9',
  primary: '#007fa3',
  primary500: '#007fa3',
  primary600: '#0e6d8c',
  primary700: '#16556e',
  primary800: '#173c4c',
  secondary200: '#f5cee1',
  secondary300: '#f7a6cf',
  secondary400: '#ed4c9d',
  secondary: '#e70073',
  secondaryInverted: 'white',
  secondary500: '#e70073',
  secondary600: '#d10069',
  secondary700: '#b7005c',
  secondary800: '#98004c',
  success200: '#e8fad7',
  success300: '#caf2a2',
  success400: '#a1ed55',
  success: '#5cb700',
  successInverted: 'white',
  success500: '#5cb700',
  success600: '#4d9801',
  success700: '#376e02',
  success800: '#234701',
  danger200: '#fad4d7',
  danger300: '#ed8893',
  danger400: '#f25a66',
  danger: '#e41625',
  danger500: '#e41625',
  danger600: '#ce1323',
  danger700: '#b4111e',
  danger800: '#850c16'
};

var defaultPalette = _defaultPalette({});

var Button = {
  base: css(["border-radius:0px;border:2px solid ", ";color:", ";height:", "rem;padding:0 ", "rem;font-size:15px;text-transform:uppercase;", ";"], function (props) {
    return props.palette === 'default' ? palette('gray700') : 'transparent';
  }, function (props) {
    return props.palette === 'default' ? palette('gray700') : palette(props.palette + "Inverted");
  }, space(11), space(4), function (props) {
    return isInteractive(props) && css(["&:focus{outline:2px solid ", ";outline-offset:0;box-shadow:none;background-color:", ";}"], function (props) {
      return props.palette === 'default' ? palette('gray800') : palette();
    }, palette());
  }),
  outlined: css(["border-width:2px;"]),
  ghost: css(["border:2px solid transparent;", ";"], function (props) {
    return isInteractive(props) && css(["&:hover{background-color:", ";color:", ";fill:", ";}&:hover:active{background-color:", ";}"], function (props) {
      return props.palette === 'default' ? palette('gray700') : palette();
    }, function (props) {
      return props.palette === 'default' ? palette('default') : palette(props.palette + "Inverted");
    }, function (props) {
      return props.palette === 'default' ? palette('default') : palette(props.palette + "Inverted");
    }, function (props) {
      return props.palette === 'default' ? darken(0.1, palette('gray700', 0, defaultPalette.gray700)(props)) : darken(0.1, palette()(props));
    });
  }),
  interactive: css(["&:focus{border:2px solid white;background-color:", ";color:", ";}", ";"], function (props) {
    return props.palette === 'default' ? palette('gray800') : palette(props.palette + "600");
  }, function (props) {
    return props.palette === 'default' ? 'white' : palette(props.palette + "Inverted");
  }, function (props) {
    return props.palette === 'default' && css(["&:hover{background-color:", ";color:white;}&:hover:active{background-color:", ";}"], palette('gray700'), palette('gray800'));
  }),
  link: css(["border:2px solid transparent;background:unset;"]),
  sizes: {
    small: css(["height:", "rem;font-size:15px;padding:0 ", "rem;"], space(8), space(4))
  }
};

var Checkbox = {
  base: css(["border-radius:0px;box-shadow:none;"])
};

var Container = {
  base: css(["", ";"], function (props) {
    return props.isFluid && css(["margin:0px;"]);
  })
};

var Heading = {
  base: css(["font-weight:", ";"], theme('fannypack.fontWeights.semibold')),
  h6: css(["font-size:1.125rem;"])
};

var Input = {
  base: css(["border-radius:0px;box-shadow:none;height:", "em;"], space(11))
};

var Label = {
  base: css(["font-size:14px;"])
};

var Select = {
  base: css(["border-radius:0px;box-shadow:none;height:", "em;"], space(10))
};

var SelectMenu = {
  ActionButton: {
    base: css(["height:", "rem;"], space(2))
  },
  Button: {
    base: css(["border:1px solid #bdbdbd;color:", ";height:", "rem;padding:0.4em 1.4em 0.4em 0.6em;text-transform:unset;", ";"], palette('text'), space(10), function (props) {
      return isInteractive(props) && css(["&:hover{background-color:unset;color:unset;}&:focus{background-color:unset;color:unset;border:1px solid ", ";outline:unset;box-shadow:", " 0px 0px 0px 1px !important;}"], palette('primary'), palette('primary'));
    })
  }
};

var medipass = {
  // Foundation
  global: global,
  webFontLoader: webFontLoader,
  layout: layout,
  fontWeights: fontWeights,
  palette: _palette,
  // Components
  Button: Button,
  Checkbox: Checkbox,
  Container: Container,
  Heading: Heading,
  Input: Input,
  Label: Label,
  Select: Select,
  SelectMenu: SelectMenu
};

var index = {
  default: defaultTheme,
  medipass: medipass
};

export default index;
