'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var __chunk_1 = require('./chunk-3b74065f.js');
var styled = require('./styled.js');
var types = require('./types.js');
var Overlay = _interopDefault(require('reakit/Overlay'));
var React = require('react');
var React__default = _interopDefault(React);
var styledTools = require('styled-tools');
var PropTypes = require('prop-types');

var OverlayContainer = function OverlayContainer(_ref) {
  var children = _ref.children,
      defaultVisible = _ref.defaultVisible,
      initialState = _ref.initialState,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["children", "defaultVisible", "initialState"]);

  return React.createElement(Overlay.Container, __chunk_1._extends({
    initialState: __chunk_1._objectSpread({
      visible: defaultVisible
    }, initialState)
  }, props), function (_ref2) {
    var visible = _ref2.visible,
        rest = __chunk_1._objectWithoutPropertiesLoose(_ref2, ["visible"]);

    return children(__chunk_1._objectSpread({
      isVisible: visible
    }, rest));
  });
};
var overlayContainerPropTypes = {
  children: PropTypes.func.isRequired,
  defaultVisible: PropTypes.bool,
  initialState: PropTypes.object
};
OverlayContainer.propTypes = overlayContainerPropTypes;
var overlayContainerDefaultProps = {
  defaultVisible: false,
  initialState: {}
};
OverlayContainer.defaultProps = overlayContainerDefaultProps;

var getPlacementAttributes = function getPlacementAttributes(props) {
  if (!props.placement) return null;

  var getHiddenAttributes = function getHiddenAttributes(_ref) {
    var transformX = _ref.transformX,
        transformY = _ref.transformY;
    return function (props) {
      return styled.css(["&[aria-hidden='true']{transform:", ";}"], "translate3d(" + (props.slide ? transformX : '0') + ", " + (props.slide ? transformY : '0') + ", 0px) " + (props.expand ? 'scale(0.01)' : ''));
    };
  };

  var placementAttributes = {
    // @ts-ignore
    top: styled.css(["top:", "em;left:50%;transform:translate3d(-50%,0,0px);", ";"], styled.space(5), getHiddenAttributes({
      transformX: '-50%',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    bottom: styled.css(["bottom:", "em;left:50%;transform:translate3d(-50%,0,0px);", ";"], styled.space(5), getHiddenAttributes({
      transformX: '-50%',
      transformY: 'calc(50% + 100%)'
    })),
    // @ts-ignore
    left: styled.css(["top:50%;left:", "em;transform:translate3d(0px,-50%,0px);", ";"], styled.space(5), getHiddenAttributes({
      transformX: 'calc(50% - 100%)',
      transformY: '-50%'
    })),
    // @ts-ignore
    right: styled.css(["top:50%;right:", "em;transform:translate3d(0px,-50%,0px);", ";"], styled.space(5), getHiddenAttributes({
      transformX: 'calc(50% + 100%)',
      transformY: '-50%'
    })),
    // @ts-ignore
    'top-start': styled.css(["top:", "em;left:", "em;transform:translate3d(0,0,0px);", ";"], styled.space(5), styled.space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    'top-end': styled.css(["top:", "em;right:", "em;transform:translate3d(0,0,0px);", ";"], styled.space(5), styled.space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% - 100%)'
    })),
    // @ts-ignore
    'bottom-end': styled.css(["bottom:", "em;right:", "em;transform:translate3d(0,0,0px);", ";"], styled.space(5), styled.space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% + 100%)'
    })),
    // @ts-ignore
    'bottom-start': styled.css(["bottom:", "em;left:", "em;transform:translate3d(0,0,0px);", ";"], styled.space(5), styled.space(5), getHiddenAttributes({
      transformX: '0',
      transformY: 'calc(50% + 100%)'
    }))
  };
  return styled.css(["top:unset;left:unset;", ";"], placementAttributes[props.placement]);
};

var OverlayHide = styled.default(Overlay.Hide).withConfig({
  displayName: "styled__OverlayHide",
  componentId: "sc-1t69wy-0"
})(["", ";"], styledTools.theme('fannypack.Overlay.Hide.base'));
var OverlayShow = styled.default(Overlay.Show).withConfig({
  displayName: "styled__OverlayShow",
  componentId: "sc-1t69wy-1"
})(["", ";"], styledTools.theme('fannypack.Overlay.Show.base'));
var OverlayToggle = styled.default(Overlay.Toggle).withConfig({
  displayName: "styled__OverlayToggle",
  componentId: "sc-1t69wy-2"
})(["", ";"], styledTools.theme('fannypack.Overlay.Toggle.base'));
var _Overlay = styled.default(Overlay).withConfig({
  displayName: "styled",
  componentId: "sc-1t69wy-3"
})(["&{", ";}", ";"], getPlacementAttributes, styledTools.theme('fannypack.Overlay.base'));

var OverlayHide$1 = React.forwardRef(function (_ref, ref) {
  var children = _ref.children,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["children"]);

  return (// @ts-ignore
    React.createElement(OverlayHide, __chunk_1._extends({}, props, {
      ref: ref
    }), children)
  );
});
var overlayHidePropTypes = {
  children: PropTypes.node,
  hide: PropTypes.func.isRequired,
  onClick: PropTypes.func
};
OverlayHide$1.propTypes = overlayHidePropTypes;
var overlayHideDefaultProps = {
  children: null,
  onClick: undefined
};
OverlayHide$1.defaultProps = overlayHideDefaultProps; // @ts-ignore

var C = OverlayHide$1;

var OverlayShow$1 = function OverlayShow$$1(_ref) {
  var children = _ref.children,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["children"]);

  return React.createElement(OverlayShow, props, children);
};
var overlayShowPropTypes = {
  children: PropTypes.node,
  onClick: PropTypes.func,
  show: PropTypes.func.isRequired
};
OverlayShow$1.propTypes = overlayShowPropTypes;
var overlayShowDefaultProps = {
  children: null,
  onClick: undefined
};
OverlayShow$1.defaultProps = overlayShowDefaultProps; // @ts-ignore

var C$1 = OverlayShow$1;

var OverlayToggle$1 = function OverlayToggle$$1(_ref) {
  var children = _ref.children,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["children"]);

  return React.createElement(OverlayToggle, props, children);
};
OverlayToggle$1.propTypes = {
  children: PropTypes.node,
  onClick: PropTypes.func,
  toggle: PropTypes.func.isRequired
};
OverlayToggle$1.defaultProps = {
  children: null,
  onClick: undefined
};
var C$2 = OverlayToggle$1;

var Overlay$1 = function Overlay$$1(_ref) {
  var children = _ref.children,
      isVisible = _ref.isVisible,
      props = __chunk_1._objectWithoutPropertiesLoose(_ref, ["children", "isVisible"]);

  return React.createElement(_Overlay, __chunk_1._extends({
    visible: isVisible
  }, props), children);
};
Overlay$1.Container = OverlayContainer;
Overlay$1.Hide = C;
Overlay$1.Show = C$1;
Overlay$1.Toggle = C$2;
var overlayPropTypes = __chunk_1._objectSpread({
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  isVisible: PropTypes.bool,
  placement: types.placementPropType
}, types.animatePropTypes, types.restrictHidePropTypes);
Overlay$1.propTypes = overlayPropTypes;
var overlayDefaultProps = __chunk_1._objectSpread({
  className: undefined,
  isVisible: false,
  placement: undefined
}, types.animateDefaultProps, types.restrictDefaultProps, {
  hideOnEsc: true
});
Overlay$1.defaultProps = overlayDefaultProps;
var C$3 = Overlay$1;

exports.Overlay = C$3;
exports.overlayPropTypes = overlayPropTypes;
exports.overlayDefaultProps = overlayDefaultProps;
exports.OverlayContainer = OverlayContainer;
exports.overlayContainerDefaultProps = overlayContainerDefaultProps;
exports.overlayContainerPropTypes = overlayContainerPropTypes;
exports.overlayHideDefaultProps = overlayHideDefaultProps;
exports.overlayHidePropTypes = overlayHidePropTypes;
exports.overlayShowDefaultProps = overlayShowDefaultProps;
exports.overlayShowPropTypes = overlayShowPropTypes;
exports.OverlayHide = C;
exports.OverlayShow = C$1;
exports.OverlayToggle = C$2;
