import * as React from 'react';
import * as PropTypes from 'prop-types';
import { Omit } from '../types';
import { LocalInputProps, InputProps } from './Input';
import { LocalFieldWrapperProps } from '../FieldWrapper/FieldWrapper';
export declare type LocalInputFieldProps = Omit<LocalFieldWrapperProps, 'children'> & LocalInputProps & {
    /** Addon component to the input (before). Similar to the addon components in Input. */
    addonBefore?: React.ReactElement<any>;
    /** Addon component to the input (after). Similar to the addon components in Input. */
    addonAfter?: React.ReactElement<any>;
    /** If addonBefore or addonAfter exists, then the addons will render vertically. */
    isVertical?: boolean;
};
export declare type InputFieldProps = LocalInputFieldProps & InputProps;
export declare const InputField: React.FunctionComponent<LocalInputFieldProps>;
export declare const inputFieldPropTypes: {
    after: PropTypes.Requireable<PropTypes.ReactElementLike>;
    a11yId: PropTypes.Requireable<string>;
    a11yLabel: PropTypes.Requireable<string>;
    autoComplete: PropTypes.Requireable<string>;
    autoFocus: PropTypes.Requireable<boolean>;
    before: PropTypes.Requireable<PropTypes.ReactElementLike>;
    children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
    className: PropTypes.Requireable<string>;
    defaultValue: PropTypes.Requireable<string>;
    disabled: PropTypes.Requireable<boolean>;
    inputRef: PropTypes.Validator<React.RefObject<any> | undefined>;
    isLoading: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    name: PropTypes.Requireable<string>;
    size: PropTypes.Validator<import("../types/props").Size>;
    max: PropTypes.Requireable<number>;
    maxLength: PropTypes.Requireable<number>;
    min: PropTypes.Requireable<number>;
    minLength: PropTypes.Requireable<number>;
    multiple: PropTypes.Requireable<boolean>;
    pattern: PropTypes.Requireable<string>;
    placeholder: PropTypes.Requireable<string>;
    readOnly: PropTypes.Requireable<boolean>;
    spellCheck: PropTypes.Requireable<boolean>;
    step: PropTypes.Requireable<number>;
    state: PropTypes.Requireable<string>;
    type: PropTypes.Requireable<string>;
    value: PropTypes.Requireable<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
    description: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    hint: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    isOptional: PropTypes.Requireable<boolean>;
    label: PropTypes.Requireable<string | PropTypes.ReactElementLike>;
    validationText: PropTypes.Requireable<string>;
    addonBefore: PropTypes.Requireable<PropTypes.ReactElementLike>;
    addonAfter: PropTypes.Requireable<PropTypes.ReactElementLike>;
    isVertical: PropTypes.Requireable<boolean>;
};
export declare const inputFieldDefaultProps: {
    after?: React.ReactElement<any> | undefined;
    a11yId: string | undefined;
    a11yLabel?: string | undefined;
    autoComplete?: string | undefined;
    autoFocus?: boolean | undefined;
    before?: React.ReactElement<any> | undefined;
    children?: React.ReactNode;
    className: string | undefined;
    defaultValue?: string | undefined;
    disabled?: boolean | undefined;
    inputRef?: React.RefObject<any> | undefined;
    isLoading?: boolean | undefined;
    isRequired: boolean | undefined;
    name?: string | undefined;
    size?: "medium" | "default" | "small" | "large" | "xlarge" | "xxlarge" | "xxxlarge" | undefined;
    max?: number | undefined;
    maxLength?: number | undefined;
    min?: number | undefined;
    minLength?: number | undefined;
    multiple?: boolean | undefined;
    pattern?: string | undefined;
    placeholder?: string | undefined;
    readOnly?: boolean | undefined;
    spellCheck?: boolean | undefined;
    step?: number | undefined;
    state: string | undefined;
    type?: string | undefined;
    value?: string | undefined;
    onBlur?: ((event: React.FocusEvent<HTMLInputElement>) => void) | undefined;
    onChange?: ((event: React.FormEvent<HTMLInputElement>) => void) | undefined;
    onFocus?: ((event: React.FocusEvent<HTMLInputElement>) => void) | undefined;
    description: undefined;
    hint: undefined;
    isOptional: undefined;
    label: undefined;
    validationText: undefined;
    addonBefore: undefined;
    addonAfter: undefined;
    isVertical: boolean;
};
declare const C: React.FunctionComponent<InputFieldProps>;
export default C;
