import * as React from 'react';
import * as PropTypes from 'prop-types';
import { InlineBlockProps as ReakitInlineBlockProps } from 'reakit/ts/InlineBlock/InlineBlock';
import { Omit } from '../types';
export declare type LocalSelectProps = {
    /** ID for the select field */
    a11yId?: string;
    /** An accessible label for the select field */
    a11yLabel?: string;
    autoComplete?: string;
    /** Automatically focus the select field */
    autoFocus?: boolean;
    className?: string;
    /** Default value of the select field */
    defaultValue?: string;
    /** Disables the select field */
    disabled?: boolean;
    /** Makes the select field span full width */
    isFullWidth?: boolean;
    /** Adds a cute loading indicator to the select field */
    isLoading?: boolean;
    /** Makes the select field required and sets aria-invalid to true */
    isRequired?: boolean;
    /** Name of the select field */
    name?: string;
    /** Select field options */
    options: Array<{
        label: string;
        value: string;
        disabled?: boolean;
    }>;
    /** Hint text to display */
    placeholder?: string;
    /** Alters the size of the select field. Can be "small", "medium" or "large" */
    size?: string;
    /** State of the select field. Can be any color in the palette. */
    state?: string;
    /** Value of the select field */
    value?: string;
    /** Function to invoke when focus is lost */
    onBlur?: React.FocusEventHandler<HTMLSelectElement>;
    /** Function to invoke when the select field has changed */
    onChange?: React.FormEventHandler<HTMLInputElement>;
    /** Function to invoke when the select field is focused */
    onFocus?: React.FocusEventHandler<HTMLSelectElement>;
};
export declare type SelectProps = Omit<Omit<ReakitInlineBlockProps, 'children'>, 'size'> & LocalSelectProps;
export declare type SelectState = {
    isPlaceholderSelected: boolean;
};
export declare const selectDefaultProps: {
    a11yId: undefined;
    a11yLabel: undefined;
    autoComplete: undefined;
    autoFocus: boolean;
    className: undefined;
    defaultValue: undefined;
    disabled: boolean;
    isFullWidth: boolean;
    isLoading: boolean;
    isRequired: boolean;
    name: undefined;
    onBlur: undefined;
    onChange: undefined;
    onFocus: undefined;
    placeholder: undefined;
    size: string;
    state: undefined;
    value: undefined;
};
export declare const selectPropTypes: {
    a11yId: PropTypes.Requireable<string>;
    a11yLabel: PropTypes.Requireable<string>;
    autoComplete: PropTypes.Requireable<string>;
    autoFocus: PropTypes.Requireable<boolean>;
    className: PropTypes.Requireable<string>;
    defaultValue: PropTypes.Requireable<string>;
    disabled: PropTypes.Requireable<boolean>;
    isFullWidth: PropTypes.Requireable<boolean>;
    isLoading: PropTypes.Requireable<boolean>;
    isRequired: PropTypes.Requireable<boolean>;
    name: PropTypes.Requireable<string>;
    options: PropTypes.Validator<any[]>;
    placeholder: PropTypes.Requireable<string>;
    size: PropTypes.Requireable<string>;
    state: PropTypes.Requireable<string>;
    value: PropTypes.Requireable<string>;
    onBlur: PropTypes.Requireable<(...args: any[]) => any>;
    onChange: PropTypes.Requireable<(...args: any[]) => any>;
    onFocus: PropTypes.Requireable<(...args: any[]) => any>;
};
export declare class Select extends React.PureComponent<LocalSelectProps, SelectState> {
    static defaultProps: {
        a11yId: undefined;
        a11yLabel: undefined;
        autoComplete: undefined;
        autoFocus: boolean;
        className: undefined;
        defaultValue: undefined;
        disabled: boolean;
        isFullWidth: boolean;
        isLoading: boolean;
        isRequired: boolean;
        name: undefined;
        onBlur: undefined;
        onChange: undefined;
        onFocus: undefined;
        placeholder: undefined;
        size: string;
        state: undefined;
        value: undefined;
    };
    static propTypes: {
        a11yId: PropTypes.Requireable<string>;
        a11yLabel: PropTypes.Requireable<string>;
        autoComplete: PropTypes.Requireable<string>;
        autoFocus: PropTypes.Requireable<boolean>;
        className: PropTypes.Requireable<string>;
        defaultValue: PropTypes.Requireable<string>;
        disabled: PropTypes.Requireable<boolean>;
        isFullWidth: PropTypes.Requireable<boolean>;
        isLoading: PropTypes.Requireable<boolean>;
        isRequired: PropTypes.Requireable<boolean>;
        name: PropTypes.Requireable<string>;
        options: PropTypes.Validator<any[]>;
        placeholder: PropTypes.Requireable<string>;
        size: PropTypes.Requireable<string>;
        state: PropTypes.Requireable<string>;
        value: PropTypes.Requireable<string>;
        onBlur: PropTypes.Requireable<(...args: any[]) => any>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
        onFocus: PropTypes.Requireable<(...args: any[]) => any>;
    };
    state: {
        isPlaceholderSelected: boolean;
    };
    handleChange: (e: any) => void;
    render: () => JSX.Element;
}
declare const C: React.FunctionComponent<SelectProps>;
export default C;
